==> pvfs-1.3.2.tgz: pvfs-1.3.2/iod/jlist.h <==
/*
 * jlist.h copyright (c) 1997 Clemson University, all rights reserved.
 *
 * Written by Rob Ross and Matt Cettei.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.eng.clemson.edu
 *           Matt Cettei mcettei@parl.eng.clemson.edu
 */

/*
 * $Log: jlist.h,v $
 * Revision 1.5  1997/11/13 22:27:06  rbross
 * *** empty log message ***
 *
 * Revision 1.4  1997/03/18 00:14:27  rbross
 * added j_new() prototype (removed jinfo_new);
 * changed jinfo to use fd_set socket set
 *
 * Revision 1.3  1997/03/14 18:14:52  rbross
 * added prototype for j_free
 *
 * Revision 1.2  1997/03/13 21:48:00  mcettei
 * *** empty log message ***
 *
 * Revision 1.1  1996/10/31 21:04:46  rbross
 * Initial revision
 *
/*/

#ifndef JLIST_H
#define JLIST_H

#include <llist.h>
#include <alist.h>

/* includes needed for using fd_sets */
#include <sys/types.h>
#include <sys/time.h>
#include <unistd.h>

static char jlist_h[] = "$Header: /projects/pvfs/pvfs-working/iod/RCS/jlist.h,v 1.5 1997/11/13 22:27:06 rbross Exp $";

typedef llist_p jlist_p;

typedef struct jinfo jinfo, *jinfo_p;

struct jinfo {
	int jobnum;			/* unique identifier for jobs			*/
	int type;
#if 0
	int sock;			/* socket where request was received */
#else
	fd_set socks;		/* list of sockets that are (or have been) in job */
	int max_nr;			/* max socket # + 1 (for use w/socks) */
#endif
	int size;			/* amount of data to be moved by this job */
	finfo_p file_p;	/* pointer to open file info */
	int lastb;			/* offset of last byte in file to be accessed by job */
	alist_p al_p;		/* list of accesses */
};

jlist_p jlist_new(void);
int j_add(jlist_p, jinfo_p);
jinfo_p j_search(jlist_p, int sock);
int j_sock_rem(jlist_p, int sock);
int j_ptr_rem(jlist_p, void *j_p);
void jlist_cleanup(jlist_p);
int jlist_dump(jlist_p);
int j_dump(void *);
void j_free(void *j_p);
jinfo_p j_new(void);

#define j_rem(__l_p, __s) j_sock_rem((__l_p), (__s))

#endif

==> pvfs-1.4.2.tgz: pvfs-1.4.2/iod/jlist.h <==
/*
 * jlist.h copyright (c) 1997 Clemson University, all rights reserved.
 *
 * Written by Rob Ross and Matt Cettei.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.eng.clemson.edu
 *           Matt Cettei mcettei@parl.eng.clemson.edu
 */

#ifndef JLIST_H
#define JLIST_H

#include <llist.h>
#include <alist.h>

/* includes needed for using fd_sets */
#include <sys/types.h>
#include <sys/time.h>
#include <unistd.h>

typedef llist_p jlist_p;

typedef struct jinfo jinfo, *jinfo_p;

struct jinfo {
	int jobnum;			/* unique identifier for jobs			*/
	int8_t type;
	int8_t nospc;		/* no space left in file -- throw away any write data */
	fd_set socks;		/* list of sockets that are (or have been) in job */
	int max_nr;			/* max socket # + 1 (for use w/socks) */
	int64_t size;			/* amount of data to be moved by this job */
	finfo_p file_p;	/* pointer to open file info */
	int64_t lastb;			/* offset of last byte in file to be accessed by job */
	alist_p al_p;		/* list of accesses */
};

jlist_p jlist_new(void);
int j_add(jlist_p, jinfo_p);
jinfo_p j_search(jlist_p, int sock);
int j_sock_rem(jlist_p, int sock);
int j_ptr_rem(jlist_p, void *j_p);
void jlist_cleanup(jlist_p);
int jlist_dump(jlist_p);
int j_dump(void *);
void j_free(void *j_p);
jinfo_p j_new(void);

#define j_rem(__l_p, __s) j_sock_rem((__l_p), (__s))

#endif
